pub struct ServerInfo {
pub bind_addrs: Vec<Bindaddr>,
pub or_addr: Option<SocketAddr>,
pub extended_or_addr: Option<SocketAddr>,
pub auth_cookie_path: Option<String>,
}Expand description
Check the server pluggable transports environment, emitting an error message and returning a non-nil error if any error is encountered. Resolves the various requested bind addresses, the server ORPort and extended ORPort, and reads the auth cookie file. Returns a ServerInfo struct.
If your program needs to know whether to call ClientSetup or ServerSetup
(i.e., if the same program can be run as either a client or a server), check
whether the TOR_PT_CLIENT_TRANSPORTS environment variable is set:
match std::env::var_os("TOR_PT_CLIENT_TRANSPORTS") {
Some(_) => {
// Client mode; call pt.ClientSetup.
}
None => {
// Server mode; call pt.ServerSetup.
}
}Fields
bind_addrs: Vec<Bindaddr>or_addr: Option<SocketAddr>extended_or_addr: Option<SocketAddr>Implementations
Sourceimpl ServerInfo
impl ServerInfo
pub async fn connect_to_or(&self) -> Result<TcpStream, Error>